@@ -294,6 +294,7 @@ class RawGuiSettings(object):
                 'doSVDBinning'          : [True, get_id(), 'bool'],
                 'numSVDBins'            : [150, get_id(), 'int'],
                 'SVDCheckShannonBins'   : [True, get_id(), 'bool'],
+                'warnLinearBaseline'    : [False, get_id(), 'bool'],
 
                 #GUI Settings:
                 'csvIncludeData'      : [None],
@@ -428,6 +429,7 @@ class RawGuiSettings(object):
                 # 'denssLimitDmaxStep'    : ['[502]', get_id(), 'text'],
                 'denssRecenter'         : [True, get_id(), 'bool'],
                 'denssRecenterStep'     : ['%s' %(list(range(501, 8002, 500))), get_id(), 'text'],
+                'denssRecenterMode'     : ['com', get_id(), 'choice'],
                 'denssPositivity'       : [True, get_id(), 'bool'],
                 'denssExtrapolate'      : [True, get_id(), 'bool'],
                 'denssShrinkwrap'       : [True, get_id(), 'bool'],
@@ -438,7 +440,7 @@ class RawGuiSettings(object):
                 'denssShrinkwrapIter'   : [20, get_id(), 'int'],
                 'denssShrinkwrapMinStep'    : ['None', get_id(), 'text'],
                 'denssConnected'        : [True, get_id(), 'bool'],
-                'denssConnectivitySteps'    : ['[500]', get_id(), 'text'],
+                'denssConnectivitySteps'    : ['None', get_id(), 'text'],
                 'denssConFeatures'      : [1, get_id(), 'int'],
                 'denssChiEndFrac'       : [0.001, get_id(), 'float'],
                 'denssAverage'          : [True, get_id(), 'bool'],
@@ -446,7 +448,6 @@ class RawGuiSettings(object):
                 'denssCutOut'           : [False, get_id(), 'bool'],
                 'denssWriteXplor'       : [False, get_id(), 'bool'],
                 'denssMode'             : ['Slow', get_id(), 'choice'],
-                'denssRecenterMode'     : ['com', get_id(), 'choice'],
                 # 'denssMinDensity'       : ['None', get_id(), 'text'],
                 # 'denssMaxDensity'       : ['None', get_id(), 'text'],
                 # 'denssFlattenLowDensity': [True, get_id(), 'bool'],
